package com.ynet.life.mvc;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.gene.flow.GENEFlow;
import com.ynet.gene.log.GENELog;
import com.ynet.gene.transaction.GENETransactionManager;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.BizLogicException;
import com.ynet.gene.web.servlet.mvc.GENEFlowExecuteResult;
import com.ynet.gene.web.servlet.mvc.GENERequestController;
import com.ynet.gene.web.servlet.mvc.InvalidInputException;
import com.ynet.gene.web.servlet.newmvc.InChargeOfMoreActions;
import com.ynet.life.exception.TranFailException;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_mvc.jar:com/ynet/life/mvc/PlatXMLViewRequestController.class */
public class PlatXMLViewRequestController extends GENERequestController implements InChargeOfMoreActions {
    protected Map simpleRequests;

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v11, types: [com.ynet.life.mvc.SimpleRequest, java.lang.Exception] */
    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (this.openMonitor) {
            this.accessInfo.newAccess();
        }
        ModelAndView modelAndView = null;
        Map model = null;
        String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        ?? r0 = (SimpleRequest) this.simpleRequests.get(actionId);
        try {
            if (r0 == 0) {
                throw new GENEException("SimpleRequest for " + actionId + " not found!");
            }
            try {
                preActionWork(request, r0);
                ModelAndView executeTheFlow = executeTheFlow(request, response);
                modelAndView = executeTheFlow;
                if (modelAndView != null) {
                    pstActionWork(request, (Context) modelAndView.getModel().get(GENEConstance.ATTR_CONTEXT), null, r0);
                }
                return executeTheFlow;
            } catch (Exception e) {
                r0.printStackTrace();
                if (e instanceof InvalidInputException) {
                    e.getModel();
                } else if (e instanceof BizLogicException) {
                    ((BizLogicException) e).getModel();
                }
                throw e;
            }
        } catch (Throwable th) {
            if (modelAndView != null) {
                pstActionWork(request, (Context) modelAndView.getModel().get(GENEConstance.ATTR_CONTEXT), null, r0);
            } else if (0 != 0) {
                pstActionWork(request, (Context) model.get(GENEConstance.ATTR_CONTEXT), null, r0);
            }
            throw th;
        }
    }

    protected ModelAndView executeTheFlow(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (isCheckDuplicateSubmit()) {
            doCheckDuplicateSubmit(request, response);
        }
        String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        SimpleRequest simpleRequest = (SimpleRequest) this.simpleRequests.get(actionId);
        Map model = new HashMap();
        GENEFlowExecuteResult result = executeGENELogic(request, response);
        model.put(GENEConstance.ATTR_CONTEXT, result.context);
        model.put(GENEConstance.ATTR_FLOW_OUTPUT, result.flow.getOutput(simpleRequest.getOpId()));
        if (result.e != null) {
            if (result.e instanceof InvalidInputException) {
                result.e.setModel(model);
                throw result.e;
            }
            throw new BizLogicException(model, result.e);
        }
        return new ModelAndView(model, new XMLView());
    }

    protected GENEFlowExecuteResult executeGENELogic4Switch(String bizId, String opId) {
        GENEFlowExecuteResult result = new GENEFlowExecuteResult();
        GENETransactionManager transactionManager = null;
        GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "begin to execute flow " + bizId + " ...");
        try {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Get flow " + bizId + "  from factory...");
            GENEFlow flow = this.geneFactory.getGENEFlow(bizId);
            result.flow = flow;
            Context context = (Context) flow.getContext().clone();
            result.context = context;
            transactionManager = (GENETransactionManager) context.getService(GENEConstance.TRX_SVC_NAME);
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Update the request data ...");
            String retValue = flow.execute(context, opId);
            if (transactionManager != null) {
                transactionManager.commit();
            }
            result.result = retValue;
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "Failed to execute flow ".concat(String.valueOf(bizId)), e);
            result.e = e;
            if (transactionManager != null) {
                transactionManager.rollback();
            }
        }
        return result;
    }

    protected GENEFlowExecuteResult executeGENELogic(HttpServletRequest request, HttpServletResponse response) {
        String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        SimpleRequest simpleRequest = (SimpleRequest) this.simpleRequests.get(actionId);
        GENEFlowExecuteResult result = new GENEFlowExecuteResult();
        GENETransactionManager transactionManager = null;
        String flowId = simpleRequest.getBizId();
        GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "begin to execute flow " + flowId + " ...");
        String opId = simpleRequest.getOpId();
        try {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Get flow " + flowId + "  from factory...");
            GENEFlow flow = this.geneFactory.getGENEFlow(flowId);
            result.flow = flow;
            Context context = (Context) flow.getContext().clone();
            result.context = context;
            transactionManager = (GENETransactionManager) context.getService(GENEConstance.TRX_SVC_NAME);
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Update the request data ...");
            doUpdateModel(request, context, flow, opId);
            doPreprocessModelData(request, context, flow, opId);
            addDataField(context, GENEConstance.SERVLET_REQUEST, request);
            preContextWork(request, context, simpleRequest);
            String retValue = flow.execute(context, opId);
            if (transactionManager != null) {
                transactionManager.commit();
            }
            result.result = retValue;
            pstContextWork(request, context, simpleRequest);
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "Failed to execute flow ".concat(String.valueOf(flowId)), e);
            result.e = e;
            if (transactionManager != null) {
                transactionManager.rollback();
            }
        }
        return result;
    }

    public boolean isInCharge(HttpServletRequest request) {
        String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        if (this.simpleRequests != null && this.simpleRequests.containsKey(actionId)) {
            return true;
        }
        return false;
    }

    public void addSimpleRequest(SimpleRequest simpleRequest) {
        if (this.simpleRequests == null) {
            this.simpleRequests = new HashMap();
        }
        this.simpleRequests.put(simpleRequest.getId(), simpleRequest);
    }

    protected void preActionWork(HttpServletRequest request, SimpleRequest simpleRequest) throws TranFailException {
    }

    protected void pstActionWork(HttpServletRequest request, Context context, Throwable throwable, SimpleRequest simpleRequest) throws TranFailException {
    }

    protected void preContextWork(HttpServletRequest request, Context context, SimpleRequest simpleRequest) throws TranFailException {
    }

    protected void pstContextWork(HttpServletRequest request, Context context, SimpleRequest simpleRequest) throws TranFailException, ObjectNotFoundException, InvalidArgumentException {
    }

    public ModelAndView handleException(HttpServletRequest request, HttpServletResponse response, Exception e) {
        Map model = new HashMap();
        model.put(GENEConstance.ATTR_EXCEPTION, e);
        return new ModelAndView(model, new XMLView());
    }
}
